==> common-dto-1.2-sources.jar: fr/ird/observe/dto/reference/DataDtoReferenceSet.java <==
package fr.ird.observe.dto.reference;

/*
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2008 - 2017 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.MoreObjects;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class DataDtoReferenceSet<R extends DataDtoReferenceSupport> extends DtoReferenceCollectionSupport<R> {

    private static final long serialVersionUID = 1L;

    public static <R extends DataDtoReferenceSupport> DataDtoReferenceSet<R> of(Class<R> referenceType, Collection<R> references) {
        return new DataDtoReferenceSet<>(referenceType, references instanceof List ? (List<R>) references : new ArrayList<>(references));
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add(PROPERTY_TYPE, type.getSimpleName())
                .toString();
    }

    protected DataDtoReferenceSet(Class<R> type, List<R> references) {
        super(type, references);
    }

}

==> common-dto-3.2-sources.jar: fr/ird/observe/dto/reference/DataDtoReferenceSet.java <==
package fr.ird.observe.dto.reference;

/*
 * #%L
 * ObServe Toolkit :: Common Dto
 * %%
 * Copyright (C) 2008 - 2018 IRD, Ultreia.io
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.MoreObjects;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class DataDtoReferenceSet<R extends DataDtoReference> extends DtoReferenceCollection<R> {

    private static final long serialVersionUID = 1L;

    public static <R extends DataDtoReference> DataDtoReferenceSet<R> of(Class<R> referenceType, Collection<R> references) {
        return new DataDtoReferenceSet<>(referenceType, references instanceof List ? (List<R>) references : new ArrayList<>(references));
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .add(PROPERTY_TYPE, type.getSimpleName())
                .toString();
    }

    protected DataDtoReferenceSet(Class<R> type, List<R> references) {
        super(type, references);
    }

}
